@@ -38,7 +38,7 @@ try:
     from .features.moments import moments
     from .morph import cerode, close, close_holes, get_structuring_elem, disk, dilate, cdilate, hitmiss, erode, cwatershed, majority_filter, open, regmin, regmax
     from .resize import imresize
-    from .stretch import stretch, as_rgb
+    from .stretch import stretch, stretch_rgb, as_rgb
     from .thin import thin
     from .thresholding import otsu, rc
     from .io import imread, imsave
@@ -48,6 +48,7 @@ try:
     from .mahotas_version import __version__
 
     from . import colors
+    from . import demos
     from . import features
     from . import morph
     from . import segmentation
@@ -143,6 +144,7 @@ __all__ = [
     'wavelet_center',
     'wavelet_decenter',
 
+    'demos',
     'morph',
     'features',
     'segmentation',
