@@ -73,8 +73,8 @@ def get_structuring_elem(A,Bc):
     elif type(Bc) == int and (len(A.shape), Bc) in translate_sizes:
         Bc = translate_sizes[len(A.shape),Bc]
     elif type(Bc) != int:
-        if len(A.shape) != len(Bc.shape):
-            raise ValueError('morph.get_structuring_elem: Bc does not have the correct number of dimensions.')
+        if A.ndim != Bc.ndim:
+            raise ValueError('morph.get_structuring_elem: Bc does not have the correct number of dimensions. [array has {} coordinates; Bc has {}.]'.format(A.ndim, Bc.ndim))
         Bc = np.asanyarray(Bc, A.dtype)
         if not Bc.flags.contiguous:
             return Bc.copy()
@@ -268,7 +268,17 @@ def cwatershed(surface, markers, Bc=None, return_lines=False):
     W = cwatershed(surface, markers, Bc=None, return_lines=False)
     W,WL = cwatershed(surface, markers, Bc=None, return_lines=True)
 
-    Seeded Watershed
+    Seeded watershed in n-dimensions
+    
+    This function computes the watershed transform on the input surface (which
+    may actually be an n-dimensional volume).
+    
+    This function requires initial seed points. A traditional way of
+    initializing watershed is to use regional minima::
+
+        minima = mh.regmin(f)
+        markers,nr_markers = mh.label(minima)
+        W = cwatershed(f, minima)
 
     Parameters
     ----------
@@ -305,8 +315,8 @@ def hitmiss(input, Bc, out=None, output=None):
     with ``1``s, while the ``0``s line up with ``0``s (``2``s correspond to
     *don't care*).
 
-    Example
-    -------
+    Examples
+    --------
 
     ::
 
